==> kubernetes-model-1.0.31-sources.jar: annotations/io/fabric8/kubernetes/api/model/GCEPersistentDiskVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class GCEPersistentDiskVolumeSourceFluentImpl<T extends GCEPersistentDiskVolumeSourceFluent<T>> extends BaseFluent<T> implements GCEPersistentDiskVolumeSourceFluent<T>{

     String fsType;     Integer partition;     String pdName;     Boolean readOnly;     Map<String, Object> additionalProperties = new HashMap();

    public String getFsType(){
    return this.fsType;
    }
    public T withFsType( String fsType){
    this.fsType=fsType; return (T) this;
    }
    public Integer getPartition(){
    return this.partition;
    }
    public T withPartition( Integer partition){
    this.partition=partition; return (T) this;
    }
    public String getPdName(){
    return this.pdName;
    }
    public T withPdName( String pdName){
    this.pdName=pdName; return (T) this;
    }
    public Boolean isReadOnly(){
    return this.readOnly;
    }
    public T withReadOnly( Boolean readOnly){
    this.readOnly=readOnly; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
GCEPersistentDiskVolumeSourceFluentImpl that = (GCEPersistentDiskVolumeSourceFluentImpl) o;
if (fsType != null ? !fsType.equals(that.fsType) :that.fsType != null) return false;
if (partition != null ? !partition.equals(that.partition) :that.partition != null) return false;
if (pdName != null ? !pdName.equals(that.pdName) :that.pdName != null) return false;
if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}

==> kubernetes-model-1.0.42-sources.jar: annotations/io/fabric8/kubernetes/api/model/GCEPersistentDiskVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class GCEPersistentDiskVolumeSourceFluentImpl<T extends GCEPersistentDiskVolumeSourceFluent<T>> extends BaseFluent<T> implements GCEPersistentDiskVolumeSourceFluent<T>{

     String fsType;     Integer partition;     String pdName;     Boolean readOnly;     Map<String, Object> additionalProperties = new HashMap();
public GCEPersistentDiskVolumeSourceFluentImpl(){
    
}
public GCEPersistentDiskVolumeSourceFluentImpl( GCEPersistentDiskVolumeSource instance ){
    this.withFsType(instance.getFsType()); this.withPartition(instance.getPartition()); this.withPdName(instance.getPdName()); this.withReadOnly(instance.getReadOnly()); 
}

    public String getFsType(){
    return this.fsType;
    }
    public T withFsType( String fsType){
    this.fsType=fsType; return (T) this;
    }
    public Integer getPartition(){
    return this.partition;
    }
    public T withPartition( Integer partition){
    this.partition=partition; return (T) this;
    }
    public String getPdName(){
    return this.pdName;
    }
    public T withPdName( String pdName){
    this.pdName=pdName; return (T) this;
    }
    public Boolean isReadOnly(){
    return this.readOnly;
    }
    public T withReadOnly( Boolean readOnly){
    this.readOnly=readOnly; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
GCEPersistentDiskVolumeSourceFluentImpl that = (GCEPersistentDiskVolumeSourceFluentImpl) o;
if (fsType != null ? !fsType.equals(that.fsType) :that.fsType != null) return false;
if (partition != null ? !partition.equals(that.partition) :that.partition != null) return false;
if (pdName != null ? !pdName.equals(that.pdName) :that.pdName != null) return false;
if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}
